Detector

Struct Detector 

pub struct Detector { /* private fields */ }
The main type for detecting tags

Implementations

Source

impl Detector

pub fn new() -> Self

Constructor

pub fn add_family(&mut self, family: Family)

Add a tag family.

The maximum number of bit errors to correct is chosen automatically from the family (see FamilyType::recommended_correction_bits). Families with a large minimum Hamming distance (e.g. tag36h11) keep the upstream default of 2, while families with a small Hamming distance (e.g. tag16h5, tag25h9) correct fewer bits to suppress false positives. Use Detector::add_family_bits to choose the correction explicitly.

We take ownership of the family to keep its lifetime.

pub fn add_family_bits(&mut self, family: Family, bits: i32)

Add a tag family

We take ownership of the family to keep its lifetime.

pub fn clear_families(&mut self)

Remove all tag families

pub fn detect(&self, im: &image_u8) -> Zarray<Detection>

Detect points in an image