pub trait ArrayDealloc {
// Required method
unsafe fn array_dealloc(zarray_ptr: *mut zarray);
}Expand description
Associates array pointer destroy function to a Zarray.
Required Methods
Sourceunsafe fn array_dealloc(zarray_ptr: *mut zarray)
unsafe fn array_dealloc(zarray_ptr: *mut zarray)
Call apriltag_x_destroy() for the correct array type.
Safety
This is unsafe because it take a pointer and destroys it. The caller must ensure it is a valid pointer.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.